SystemOrganization addCategory: #'Xtreams-TerminalsTests'!

XTFiniteReadingWritingTests subclass: #XTBlockClosureReadingWritingTest
	instanceVariableNames: 'collection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTBlockClosureReadingWritingTest methodsFor: 'initialize-release' stamp: 'MartinKobetic 1/11/2011 17:53'!
setUp

	collection := OrderedCollection new.
	input := [ collection isEmpty ifTrue: [ Incomplete zero raise ]. collection removeFirst ] reading.
	input contentsSpecies: ByteArray.
	output := [ :x | collection addLast: x ] writing.
	output contentsSpecies: ByteArray.! !

XTFiniteReadingWritingTests subclass: #XTBufferReadingWritingTest
	instanceVariableNames: 'buffer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTBufferReadingWritingTest methodsFor: 'initialize-release' stamp: 'nice 10/20/2010 22:59'!
setUp

	buffer := XTBuffer on: ByteArray new.
	input := buffer reading.
	output := buffer writing.! !

XTFiniteReadingWritingTests subclass: #XTElasticBufferReadingWritingTest
	instanceVariableNames: 'buffer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTElasticBufferReadingWritingTest methodsFor: 'initialize-release' stamp: 'nice 10/20/2010 22:59'!
setUp

	buffer := XTElasticBuffer on: ByteArray new.
	input := buffer reading.
	output := buffer writing.! !

XTFiniteReadingWritingTests subclass: #XTFiniteBoundlessReadingWritingTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTFiniteBoundlessReadingWritingTests commentStamp: 'nice 3/3/2012 22:01' prior: 0!
Tests for terminals that can be positioned past their current length.!

XTFiniteBoundlessReadingWritingTests subclass: #XTCollectionReadingWritingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTCollectionReadingWritingTest methodsFor: 'accessing' stamp: 'nice 10/20/2010 22:54'!
input

	^input ifNil: [ input := (self output close; terminal) reading ]! !

!XTCollectionReadingWritingTest methodsFor: 'accessing' stamp: 'nice 10/20/2010 22:54'!
output

	^output ifNil: [ output := ByteArray new writing ]! !

!XTCollectionReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 3/3/2012 21:59'!
testBoundlessArraySeek
	output := Array new writing.
	self output
		++ 9;
		write: 10;
		close.
	self assert: self input rest = ((Array new: 10 withAll: nil) at: 10 put: 10; yourself)! !

!XTCollectionReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 3/3/2012 21:59'!
testBoundlessCharacterSeek
	output := String new writing.
	self output
		++ 9;
		write: 'a';
		close.
	self assert: self input rest = ((String new: 10 withAll: (Character codePoint: 0)) at: 10 put: $a; yourself)! !

!XTCollectionReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 10/20/2010 22:55'!
testInsert
	self output write: #[ 1 2 3 4 7 8 9 0 ].
	self output -- 4.
	self output insert: #[ 5 6 ].
	self output -= 0. "Have to seek to the end otherwise output gets truncated when we close it"
	self assert: (self input read: 10) = #[ 1 2 3 4 5 6 7 8 9 0 ]! !

!XTCollectionReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 10/20/2010 23:21'!
testReadWriteLargeAmount
	| data |
	1 to: 10 do: [:each | 
		output := input := nil.
		self output put: 1. self assert: self input get = 1].
	#( 64 1024 2048 4096 8192 ) do: [:dataSize |
		output := input := nil.
		data := ByteArray new: dataSize.
		1 to: data size do: [:i | data at: i put: (i - 1) \\ 256].
		self	timeout:	1000 milliseconds
			server:	[1 to: 10 do: [:each | self output write: data]. true]
			client: 	[(1 to: 10) inject: true into: [:pass :each | pass and: [(self input read: data size) = data]]]]! !

!XTCollectionReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 12/31/2010 00:10'!
testWriteFromCollectionAt

	| data |
	data := #[1 2 3 4 5 6 7].
	self assert: (self output write: 4 from: data at: 1) = 4.
	self assert: (self output write: 3 from: data at: 5) = 3.
	self assert: (self input read: 4) = (data first: 4).
	self assert: (self input read: 3) = (data last: 3)! !

!XTCollectionReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testWriteFromStream
	| data |
	data := #[ 1 2 3 4 ] reading.
	self assert: (self output write: 3 from: data) = 3.
	self assert: (self output write: 1 from: data) = 1.
	self assert: (self input read: 3) = #[ 1 2 3 ].
	self assert: self input get = 4.
	self assert: (
		[	self output write: 2 from: data. false
		] on: Incomplete do: [ :eos |
			eos count = 0 ])! !

XTFiniteBoundlessReadingWritingTests subclass: #XTFileReadingWritingTest
	instanceVariableNames: 'file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTFileReadingWritingTest methodsFor: 'accessing' stamp: 'nice 10/15/2010 11:43'!
input
	^input ifNil: [input := file reading]! !

!XTFileReadingWritingTest methodsFor: 'initialize-release' stamp: 'nice 10/15/2010 20:43'!
setUp

	file := FileDirectory default / (self class name , '-' , testSelector).
	output := file writing.
	input := nil! !

!XTFileReadingWritingTest methodsFor: 'initialize-release' stamp: 'nice 10/15/2010 14:49'!
tearDown

	input ifNotNil: [:f | f close].
	output ifNotNil: [:f | f close].
	[FileDirectory default deleteFileNamed: file pathParts last] ifError: []! !

!XTFileReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 10/14/2010 23:02'!
testInsert
	"Do nothing, since files are not expected to implement insert:* "! !

!XTFiniteBoundlessReadingWritingTests methodsFor: 'testing' stamp: 'nice 3/3/2012 22:02'!
testBoundlessExplore
	self output
		explore: [
			self output
				position: 9;
				write: 10];
		write: #[1 2 3 4 5 6 7 8 9];
		++ 1;
		close.
	self assert: self input rest = #[1 2 3 4 5 6 7 8 9 10]! !

!XTFiniteBoundlessReadingWritingTests methodsFor: 'testing' stamp: 'nice 3/3/2012 22:02'!
testBoundlessExploreClip
	self output
		explore: [
			self output
				position: 9;
				write: 10];
		write: #[1 2 3 4 5 6 7 8 9];
		close.
	self assert: self input rest = #[1 2 3 4 5 6 7 8 9]! !

!XTFiniteBoundlessReadingWritingTests methodsFor: 'testing' stamp: 'nice 3/3/2012 22:02'!
testBoundlessPositioningSeek
	self output
		position: 9;
		write: 10;
		close.
	self assert: self input rest = #[0 0 0 0 0 0 0 0 0 10]! !

!XTFiniteBoundlessReadingWritingTests methodsFor: 'testing' stamp: 'nice 3/3/2012 22:02'!
testBoundlessSeek
	self output
		++ 9;
		write: 10;
		close.
	self assert: self input rest = #[0 0 0 0 0 0 0 0 0 10]! !

!XTFiniteBoundlessReadingWritingTests methodsFor: 'testing' stamp: 'nice 3/3/2012 22:02'!
testWritePositioningSeek

	| record out |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	out := self output positioning.
	out	write: record.
	self assert: (out -- 7) = 7.
	self assert: out position = 3.
	self assert: (out ++ 3) = 3.
	self assert: out position = 6.
	self assert: (out ++ record size) = record size.
	out close.
	self assert: (self input read: record size) = record! !

!XTFiniteBoundlessReadingWritingTests methodsFor: 'testing' stamp: 'nice 3/3/2012 22:02'!
testWritePositioningSeekFrom

	| record out |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	out := self output positioning.
	out	write: record.
	self assert: (out += 3) = 3.
	self assert: out position = 3.
	self assert: (out -= 4) = 4.
	self assert: out position = 6.
	self assert: ([ out -= (record size + 6) ] on: Incomplete do: [:ex | ex count]) = record size.
	self assert: out position = 0.
	self assert: (out += (record size + 6)) = (record size + 6).
	self assert: out position = (record size + 6).
	out close.
	self assert: (self input read: record size) = record! !

XTFiniteReadingWritingTests subclass: #XTRingBufferReadingWritingTest
	instanceVariableNames: 'buffer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTRingBufferReadingWritingTest methodsFor: 'initialize-release' stamp: 'nice 10/20/2010 22:59'!
setUp

	buffer := XTRingBuffer on: (ByteArray new: 8192).
	input := buffer reading.
	output := buffer writing.! !

!XTRingBufferReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 10/9/2010 22:35'!
testReadWriteLargeAmount
	
	"does not work on limited size ring buffer"! !

!XTRingBufferReadingWritingTest methodsFor: 'tests - transforming' stamp: 'nice 10/9/2010 22:35'!
testWriteCollectingMultipleBufferSize

	"does not work on limited size ring buffer"! !

XTFiniteReadingWritingTests subclass: #XTSocketReadingWritingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTSocketReadingWritingTest methodsFor: 'accessing' stamp: 'nice 10/14/2010 22:41'!
defaultTimeout
	"With sockets, be patient"

	^30 "seconds"! !

!XTSocketReadingWritingTest methodsFor: 'initialize-release' stamp: 'fbs 4/5/2013 09:57'!
setUp

	| listener sync |
	Socket initializeNetwork.
	sync := Semaphore new.
	listener := Socket newTCP.
	[	listener listenOn: 9999 backlogSize: 10.
		[	output := Socket newTCP.
			output connectTo: #[127 0 0 1] port: listener port waitForConnectionFor: 2.
			sync signal.
		] fork.	
		input := (listener waitForAcceptFor: 1).
		sync wait.
	] ensure: [ listener close ].

	input := input reading.
	output := output writing.! !

!XTSocketReadingWritingTest methodsFor: 'blocking utilities' stamp: 'nice 10/14/2010 22:17'!
timeout: timeoutDuration server: serverBlock client: clientBlock
	^self concurrentTimeout: timeoutDuration server: serverBlock client: clientBlock! !

TestCase subclass: #XTBlockClosureTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTBlockClosureTest methodsFor: 'testing' stamp: 'nice 7/9/2011 01:13'!
testOneArgumentReading
	self assert:
		([:out | 1 to: 10 do: [:i | out put: i]] reading
			contentsSpecies: ByteArray;
			read: 5) = #[ 1 2 3 4 5 ]! !

XTInfiniteReadingWritingTests subclass: #XTSharedQueueReadingWritingTest
	instanceVariableNames: 'queue'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-TerminalsTests'!

!XTSharedQueueReadingWritingTest methodsFor: 'initialize-release' stamp: 'nice 10/20/2010 23:00'!
setUp

	queue := SharedQueue new.
	(input := queue reading) contentsSpecies: ByteArray.
	(output := queue writing) contentsSpecies: ByteArray! !
